<?php
namespace Teknisa\CDP\Modules\Producao\Controllers;

use Teknisa\CDP\Modules\Producao\Services\Ger11800InspecaoService;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\CDP\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;

class Ger11800InspecaoController extends TeknisaCrud {

    protected $dataSourceName = "inspecao_inspecao";
    protected $dataSourceNameToSave = "inspecao";
    protected $environment;
    protected $entityManager;
    protected $newCode;
    protected $Ger11800InspecaoService;

    public function __construct($crudService, $parameterBag, $environment, $entityManager, $newCode, Ger11800InspecaoService $Ger11800InspecaoService) {
        parent::__construct($crudService, $parameterBag);
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->newCode = $newCode;
        $this->Ger11800InspecaoService = $Ger11800InspecaoService;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {

        $filterCriteria = $request->getFilterCriteria();
        $conditions     = $filterCriteria->getConditions();

        if(count($conditions) == 0) {
            $filterCriteria->addCondition("CDARVINSPECANTE", "=", null);
        }
        
        parent::find($request, $response);
        
        $dataSets = $response->getDataSets();
        if (count($dataSets) > 0) {
            $rows = $dataSets[0]->getRows();
            $rows = array_map(function($row) {
                $row['_hasChild'] = $row['HASCHILD'] === 'true' ? true : false;
                unset($row['HASCHILD']);
                return $row;
            }, $rows);
    
        $response->setDataSets(array(new DataSet('inspecao_inspecao', $rows)));
        }
    }
    
    public function saveInspecProd(DTO\Request $request, DTO\Response $response) {
        try {  
            $row = $request->getRow();
            $row['NRSEQINSPRO'] = $this->newCode->getCodeByTableName('NRSEQINSPRO', $this->environment->getNrOrgTrab(), $interval = 1, $colSize = 3);
            
            $newCode = array();
            array_push($newCode, $row);
            $dataSet = new DataSet ('data',$newCode);
            $response->addDataSet($dataSet);
                    
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function save(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        $dataSourceNameToSave = "inspecao";
        
        try {  
            if($row['__is_new']){
                $verificaPai = $this->Ger11800InspecaoService->verificaPai($row);
                $row['CDINSPECAO'] = $this->newCode->getCodeByTableName('CDINSPECAO', $this->environment->getNrOrgTrab());
            } else {
                $connection = $this->entityManager->getConnection();
                $connection->beginTransaction();
            }
            parent::save($request, $response);
            $this->entityManager->commit();
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function delete(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try {
            
            $verificaDelete = $this->Ger11800InspecaoService->verificaDelete($row);
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function updateDesc(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            $this->Ger11800InspecaoService->updateDesc($row);
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

}